<?php

    /** @noinspection PhpMissingFieldTypeInspection */

    namespace FederationLib\Objects;

    use FederationLib\Interfaces\SerializableObjectInterface;

    class PeerRecord implements SerializableObjectInterface
    {
        /**
         * @var string
         */
        private $federated_address;

        /**
         * @var string
         */
        private $client_first_seen;

        /**
         * @var string
         */
        private $client_last_seen;

        /**
         * @var string|null
         */
        private $active_restriction;

        /**
         * @var int
         */
        private $discovered_timestamp;

        /**
         * @var int
         */
        private $seen_timestamp;

        /**
         * Returns the Standard Federated Address for the peer
         *
         * @return string
         */
        public function getFederatedAddress(): string
        {
            return $this->federated_address;
        }

        /**
         * Returns the client UUID that first saw the peer
         *
         * @return string
         */
        public function getClientFirstSeen(): string
        {
            return $this->client_first_seen;
        }

        /**
         * Returns the client UUID that last saw the peer
         *
         * @return string
         */
        public function getClientLastSeen(): string
        {
            return $this->client_last_seen;
        }

        /**
         * Optional. Returns the active restriction ID for the peer
         * This is only available if the peer is currently restricted
         *
         * @return string|null
         */
        public function getActiveRestriction(): ?string
        {
            return $this->active_restriction;
        }

        /**
         * Returns the Unix Timestamp for when the peer was first discovered by a client
         *
         * @return int
         */
        public function getDiscoveredTimestamp(): int
        {
            return $this->discovered_timestamp;
        }

        /**
         * Returns the Unix Timestamp for when the peer was last seen by a client
         *
         * @return int
         */
        public function getSeenTimestamp(): int
        {
            return $this->seen_timestamp;
        }

        /**
         * Returns an array representation of the object
         *
         * @return array
         */
        public function toArray(): array
        {
            return [
                'federated_address' => $this->federated_address,
                'client_first_seen' => $this->client_first_seen,
                'client_last_seen' => $this->client_last_seen,
                'active_restriction' => $this->active_restriction,
                'discovered_timestamp' => $this->discovered_timestamp,
                'seen_timestamp' => $this->seen_timestamp,
            ];
        }

        /**
         * Constructs object from an array representation
         *
         * @param array $array
         * @return PeerRecord
         */
        public static function fromArray(array $array): PeerRecord
        {
            $object = new self();

            $object->federated_address = $array['federated_address'] ?? null;
            $object->client_first_seen = $array['client_first_seen'] ?? null;
            $object->client_last_seen = $array['client_last_seen'] ?? null;
            $object->active_restriction = $array['active_restriction'] ?? null;
            $object->discovered_timestamp = $array['discovered_timestamp'] ?? null;
            $object->seen_timestamp = $array['seen_timestamp'] ?? null;

            return $object;
        }
    }